==> EntitySyncer-0.0.2-sources.jar: org/openzen/entitysyncer/live/field/LiveObjectField.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.openzen.entitysyncer.live.field;

import org.openzen.entitysyncer.live.LiveBool;
import org.openzen.entitysyncer.live.LiveDouble;
import org.openzen.entitysyncer.live.LiveFloat;
import org.openzen.entitysyncer.live.LiveInt;
import org.openzen.entitysyncer.live.LiveListener;
import org.openzen.entitysyncer.live.LiveLong;
import org.openzen.entitysyncer.live.LiveObject;
import org.openzen.entitysyncer.live.LiveString;
import org.openzen.entitysyncer.live.LiveSubscription;
import org.openzen.entitysyncer.live.Subscribable;
import org.openzen.entitysyncer.structured.StructuredObject;

/**
 *
 * @author Hoofdgebruiker
 */
public class LiveObjectField<T extends StructuredObject> extends Subscribable implements LiveField, LiveObject<T> {
	private T value;
	
	public LiveObjectField(T value) {
		this.value = value;
	}
	
	@Override
	public T get() {
		return value;
	}
	
	public void set(T value) {
		this.value = value;
		publish();
	}

	@Override
	public void setBool(boolean value) {
		throw new ClassCastException("Cannot convert bool to object");
	}

	@Override
	public void setInt(int value) {
		throw new ClassCastException("Cannot convert int to object");
	}

	@Override
	public void setLong(long value) {
		throw new ClassCastException("Cannot convert long to object");
	}

	@Override
	public void setFloat(float value) {
		throw new ClassCastException("Cannot convert float to object");
	}

	@Override
	public void setDouble(double value) {
		throw new ClassCastException("Cannot convert double to object");
	}

	@Override
	public void setString(String value) {
		throw new ClassCastException("Cannot convert string to object");
	}

	@Override
	public void setObject(StructuredObject value) {
		set((T) value);
	}

	@Override
	public LiveBool asBool() {
		throw new ClassCastException("Cannot convert object to bool");
	}

	@Override
	public boolean asBoolValue() {
		throw new ClassCastException("Cannot convert object to bool");
	}

	@Override
	public LiveInt asInt() {
		throw new ClassCastException("Cannot convert object to int");
	}

	@Override
	public int asIntValue() {
		throw new ClassCastException("Cannot convert object to int");
	}

	@Override
	public LiveLong asLong() {
		throw new ClassCastException("Cannot convert object to long");
	}

	@Override
	public long asLongValue() {
		throw new ClassCastException("Cannot convert object to long");
	}

	@Override
	public LiveFloat asFloat() {
		throw new ClassCastException("Cannot convert object to float");
	}

	@Override
	public float asFloatValue() {
		throw new ClassCastException("Cannot convert object to float");
	}

	@Override
	public LiveDouble asDouble() {
		throw new ClassCastException("Cannot convert object to double");
	}

	@Override
	public double asDoubleValue() {
		throw new ClassCastException("Cannot convert object to double");
	}

	@Override
	public LiveString asString() {
		throw new ClassCastException("Cannot convert object to string");
	}

	@Override
	public String asStringValue() {
		throw new ClassCastException("Cannot convert object to string");
	}

	@Override
	public LiveObject<?> asObject() {
		return this;
	}

	@Override
	public StructuredObject asObjectValue() {
		return value;
	}
}

==> EntitySyncer-0.0.4-sources.jar: org/openzen/entitysyncer/live/field/LiveObjectField.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.openzen.entitysyncer.live.field;

import org.openzen.entitysyncer.live.LiveBool;
import org.openzen.entitysyncer.live.LiveDouble;
import org.openzen.entitysyncer.live.LiveFloat;
import org.openzen.entitysyncer.live.LiveInt;
import org.openzen.entitysyncer.live.LiveLong;
import org.openzen.entitysyncer.live.LiveObject;
import org.openzen.entitysyncer.live.LiveObjectList;
import org.openzen.entitysyncer.live.LiveString;
import org.openzen.entitysyncer.live.Subscribable;
import org.openzen.entitysyncer.structured.StructuredObject;

/**
 *
 * @author Hoofdgebruiker
 */
public class LiveObjectField<T extends StructuredObject> extends Subscribable implements LiveField, LiveObject<T> {
	private T value;
	
	public LiveObjectField(T value) {
		this.value = value;
	}
	
	@Override
	public T get() {
		return value;
	}
	
	public void set(T value) {
		this.value = value;
		publish();
	}

	@Override
	public void setBool(boolean value) {
		throw new ClassCastException("Cannot convert bool to object");
	}

	@Override
	public void setInt(int value) {
		throw new ClassCastException("Cannot convert int to object");
	}

	@Override
	public void setLong(long value) {
		throw new ClassCastException("Cannot convert long to object");
	}

	@Override
	public void setFloat(float value) {
		throw new ClassCastException("Cannot convert float to object");
	}

	@Override
	public void setDouble(double value) {
		throw new ClassCastException("Cannot convert double to object");
	}

	@Override
	public void setString(String value) {
		throw new ClassCastException("Cannot convert string to object");
	}

	@Override
	public void setObject(StructuredObject value) {
		set((T) value);
	}

	@Override
	public LiveBool asBool() {
		throw new ClassCastException("Cannot convert object to bool");
	}

	@Override
	public boolean asBoolValue() {
		throw new ClassCastException("Cannot convert object to bool");
	}

	@Override
	public LiveInt asInt() {
		throw new ClassCastException("Cannot convert object to int");
	}

	@Override
	public int asIntValue() {
		throw new ClassCastException("Cannot convert object to int");
	}

	@Override
	public LiveLong asLong() {
		throw new ClassCastException("Cannot convert object to long");
	}

	@Override
	public long asLongValue() {
		throw new ClassCastException("Cannot convert object to long");
	}

	@Override
	public LiveFloat asFloat() {
		throw new ClassCastException("Cannot convert object to float");
	}

	@Override
	public float asFloatValue() {
		throw new ClassCastException("Cannot convert object to float");
	}

	@Override
	public LiveDouble asDouble() {
		throw new ClassCastException("Cannot convert object to double");
	}

	@Override
	public double asDoubleValue() {
		throw new ClassCastException("Cannot convert object to double");
	}

	@Override
	public LiveString asString() {
		throw new ClassCastException("Cannot convert object to string");
	}

	@Override
	public String asStringValue() {
		throw new ClassCastException("Cannot convert object to string");
	}

	@Override
	public LiveObject<?> asObject() {
		return this;
	}

	@Override
	public StructuredObject asObjectValue() {
		return value;
	}

	@Override
	public LiveObjectList<?> asObjectList() {
		throw new ClassCastException("Cannot convert object to object list");
	}
}
